# MarketplaceApp


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [readonly] 
**name** | **str** |  | 
**short_description** | **str** |  | 
**long_description** | **str** |  | 
**creator** | **bool, date, datetime, dict, float, int, list, str, none_type** |  | [readonly] 
**scopes** | **[str]** |  | [readonly] 
**images** | [**[MarketplaceAppImage]**](MarketplaceAppImage.md) |  | [readonly] 
**organization** | **bool, date, datetime, dict, float, int, list, str, none_type** |  | [readonly] 
**activation_webhook_url** | **str, none_type** |  | [optional] 
**post_activation_redirect_uri** | **str, none_type** |  | [optional] 
**viewer_plugins_urls** | **[str], none_type** |  | [optional] 
**settings_url** | **str, none_type** | this URL will be called with query params ?cloud_id&#x3D; | [optional] 
**is_public** | **bool** |  | [optional] 
**tags** | **[str]** |  | [optional] 
**logo** | **str, none_type** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


